Tests
=====

The tests for a component ``X.hpp`` are located next to the corresponding ``X.cpp`` file in ``X_t.cpp``.

Generally they are self contained, but some require additional explanation, which is given here:

.. toctree::

   tests/diffusion
